@@ -100,6 +100,11 @@ public final class UnifiedInboxProperties extends AbstractProtocolProperties imp
         return mailProperties.getMailFetchLimit();
     }
 
+    @Override
+    public boolean hideInlineImages() {
+        return mailProperties.hideInlineImages();
+    }
+
     @Override
     public boolean isAllowNestedDefaultFolderOnAltNamespace() {
         return mailProperties.isAllowNestedDefaultFolderOnAltNamespace();
